# -*- coding: utf-8 -*-
'''
Plytix Retailers SDK for Python
===============================

The Plytix Retailers SDK for Python is a library designed to simplify the access to the Plytix Retailers API to applications developed in Python. The library gives you an easy way to manage your authentication and to consume the Retailers API services. Thanks to the Plytix Retailers SDK for Python, you can quickly integrate our platform in your site's back end.

You will find the all documentation and examples of how to use it at `the Plytix for developers page <https://plytix.com/developers/retailers_api/sdk/python/index.html>`_.

Plytix Retailers SDK for Python is easy to use
----------------------------------------------

.. code-block:: python

   from plytix.retailers.client import PlytixRetailersClient

   client = PlytixRetailersClient('api-key', 'api-pwd')

Once you have the client, you can start to consume the Plytix Retailers API's services immediately. For example, you get a list of all sites you manage with:

.. code-block:: python

   sites = client.sites.list()
   for site in sites:
       print site.name

Only a few lines are needed to get a list of the sites you manage at Plytix. Quick and easy.


Links
-----

* `Plytix website <https://plytix.com>`_
* `Documentation <https://plytix.com/developers/retailers_api/sdk/python/index.html>`_
* `Development version <https://bitbucket.org/plytixdevs/plytix-sdk-python>`_

'''



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


setup(
    name='plytix-retailers-sdk',
    version='0.2.1',
    description="Plytix Retailers SDK for Python",
    long_description=__doc__,
    author=u'Daniel Sánchez Prolongo',
    author_email='dani@plytix.com',
    url='https://bitbucket.org/plytixdevs/plytix-sdk-python',
    packages=[
        'plytix',
    ],
    package_dir={'plytix':
                 'plytix'},
    include_package_data=True,
    install_requires=[
        'requests==2.5.3',
    ],
    license="MIT",
    zip_safe=False,
    keywords='plytix',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
    ],
    test_suite='nose.collector',
    tests_require=[
        'requests==2.5.3',
        'httpretty',
        'nose',
        'coverage',
        'rednose',
    ],
)
